======
ArtPop
======
|CI|

An engine for generating realistic mock images of **Art**\ ificial Stellar **Pop**\ ulations.

Documentation 
-------------
|Doc Status|

The code documentation is hosted on `Read the Docs <https://artpop.readthedocs.io>`_.

License
-------
|License|

``ArtPop`` is open-source software made available under the 
`MIT License <https://github.com/ArtificialStellarPopulations/ArtPop/blob/main/LICENSE>`_.

.. |CI| image:: https://github.com/ArtificialStellarPopulations/ArtPop/actions/workflows/build.yml/badge.svg
   :target: https://github.com/ArtificialStellarPopulations/ArtPop/actions/workflows/build.yml
.. |Doc Status| image:: https://readthedocs.org/projects/artpop/badge/?version=latest
   :target: https://artpop.readthedocs.io/en/latest/?badge=latest
.. |License| image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat
   :target: https://github.com/ArtificialStellarPopulations/ArtPop/blob/main/LICENSE

